pub enum LockFreePushManyErr {
NotEnoughSpace,
ShouldWait,
}Expand description
Represents the possible errors that can occur when lock-free pushing many values into a queue.
Variants
NotEnoughSpace
The queue was full.
ShouldWait
The queue should wait for another operation to finish.